Again rename getkey() and setkey() for FreeBSD.

diff --git a/programs/winecfg/winecfg.c b/programs/winecfg/winecfg.c
index 7e7d45e..f9e630d 100644
--- a/programs/winecfg/winecfg.c
+++ b/programs/winecfg/winecfg.c
@@ -71,7 +71,7 @@
 
 
 /**
  * getkey: Retrieves a configuration value from the registry
  *
  * char *subkey : the name of the config section
  * char *name : the name of the config value
@@ -81,7 +81,7 @@
  * not. Caller is responsible for releasing the result.
  *
  */
-static char *getkey (char *subkey, char *name, char *def)
+static char *get_config_key (char *subkey, char *name, char *def)
 {
     LPBYTE buffer = NULL;
     DWORD len;
@@ -129,7 +129,7 @@
 }
 
 /**
  * setkey: convenience wrapper to set a key/value pair
  *
  * const char *subKey : the name of the config section
  * const char *valueName : the name of the config value
@@ -139,7 +139,7 @@
  *
  * If valueName or value is NULL, an empty section will be created
  */
-int setkey(const char *subkey, const char *name, const char *value) {
+int set_config_key(const char *subkey, const char *name, const char *value) {
     DWORD res = 1;
     HKEY key = NULL;
 
@@ -258,7 +258,7 @@
     }
 
     /* no, so get from the registry */
-    val = getkey(path, name, def);
+    val = get_config_key(path, name, def);
 
     WINE_TRACE("returning %s\n", val);
 
@@ -445,7 +445,7 @@
     if (s->value)
     {
 	WINE_TRACE("Setting %s:%s to '%s'\n", s->path, s->name, s->value);
-        setkey(s->path, s->name, s->value);
+        set_config_key(s->path, s->name, s->value);
     }
     else
     {
@@ -71,7 +71,7 @@
 
 /**
- * getkey: Retrieves a configuration value from the registry
+ * get_config_key: Retrieves a configuration value from the registry
  *
  * char *subkey : the name of the config section
@@ -129,7 +129,7 @@
 
 /**
- * setkey: convenience wrapper to set a key/value pair
+ * set_config_key: convenience wrapper to set a key/value pair
  *
  * const char *subKey : the name of the config section